/*
 * @Description:
 * @Author: leizhe
 * @Date: 2021-10-26 14:27:34
 * @LastEditTime: 2021-10-26 15:16:07
 * @LastEditors: leizhe
 */
import React, { useState, useEffect } from 'react';
import {
  Table,
  Tooltip,
  Spin,
  Modal,
  Form,
  Input,
  Space,
  Popconfirm,
  notification,
  message,
  Row,
  Col,
  Button,
  Upload,
} from 'antd';
import {
  EditTwoTone,
  DeleteOutlined,
  CloudSyncOutlined,
  SearchOutlined,
  PlusSquareFilled,
  MinusCircleOutlined,
  PlusOutlined,
  LogoutOutlined,
  DownloadOutlined,
  UploadOutlined,
} from '@ant-design/icons';
import styles from './search.less';
import {
  GetDataDictionaryList,
  EditDataDictionary,
  AddDataDictionary,
  DeleteDataDictionary,
  AddDataDictionaryList,
  SearchDataDictionaryList,
  ExportDataDictionary,
  ImportDataDictionary,
} from '@/services/dataCenter/api';

const Search = () => {
  const [searchData, setSearchData] = useState([]); // 搜索框表格数据
  const [treeLoading, setTreeLoading] = useState(false);
  const [searchWord, setSearchWord] = useState(''); // 关键字
  const columns2 = [
    {
      title: () => <span className={styles.font}>名称</span>,
      dataIndex: 'nodeName',
      key: 'nodeName',
    },
    {
      title: () => <span className={styles.font}>值</span>,
      dataIndex: 'nodeValue',
      width: 400,
      key: 'nodeValue',
      render: record => {
        if (!record) {
          return '-';
        }
        return record;
      },
    },
    {
      title: () => <span className={styles.font}>操作</span>,
      key: 'action',
      width: 100,
      align: 'center',
      render: record => (
        <Space>
          <Tooltip title="编辑">
            <EditTwoTone
              onClick={() => {
                setSelect(record);
                if (record.parentID === '-1') {
                  setSelectColor(record);
                }
                if (record.parentID === '-1' || record.parentID === null) {
                  setEditVisible1(true);
                } else {
                  setEditVisible(true);
                }
                editForm.setFieldsValue({
                  nodeName: record.nodeName,
                  nodeValue: record.nodeValue,
                });
              }}
              style={{ fontSize: '16px' }}
            />
          </Tooltip>
          <div onClick={e => e.stopPropagation()}>
            <Tooltip title="删除">
              <Popconfirm
                title="是否确认删除该数据,删除一级目录数据会将其二级目录子数据一起删除？"
                okText="确认"
                cancelText="取消"
                onConfirm={submitDelete}
              >
                <DeleteOutlined
                  onClick={() => {
                    setSelect(record);
                    if (record.parentID === '-1') {
                      setSelectColor(record);
                    }
                  }}
                  style={{
                    fontSize: '16px',
                    margin: '0px 10px',
                    color: '#e86060',
                  }}
                />
              </Popconfirm>
            </Tooltip>
          </div>
        </Space>
      ),
    },
  ];

  const sumbitSearch = () => {
    SearchDataDictionaryList({ key: searchWord }).then(res => {
      if (res.code === 0) {
        setSearchData(res.data);
      }
      // else {
      //     notification.error({
      //         message: '提交失败',
      //         description: res.message,
      //     })
      // }
    });
  };

  // 获取搜索框的值
  const handleSearch = e => {
    setSearchWord(e.target.value);
  };

  const pagenation = {
    showTotal: (total, range) => `第${range[0]}-${range[1]} 条/共 ${total} 条`,
    pageSizeOptions: [10, 20, 50, 100],
    defaultPageSize: '20',
    showQuickJumper: true,
    showSizeChanger: true,
  };
  return (
    <>
      <Spin tip="loading..." spinning={treeLoading}>
        <div className={styles.containerBox}>
          <div className={styles.config}>
            <div className={styles.title} />
            <div className={styles.btn}>
              <Search
                style={{ width: 470, marginBottom: 25 }}
                placeholder="输入关键字"
                onSearch={sumbitSearch}
                onChange={e => handleSearch(e)}
                enterButton
                value={searchWord}
              />
            </div>
          </div>

          <Table
            size="small"
            bordered
            key=""
            columns={columns2}
            dataSource={searchData}
            scroll={{ y: 'calc(100vh - 300px)' }}
            // rowClassName={setRowClassName}
            // onRow={record => ({
            //     onClick: () => {
            //         setSelect(record);
            //         setSelectColor(record);
            //         setSelectID(record.nodeID);
            //     },
            // })}
            pagination={pagenation}
          />
        </div>
      </Spin>
    </>
  );
};

export default Search;
